﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Collections.ObjectModel;

using MindFusion.Charting;
using MindFusion.Charting.WinForms;
using MindFusion.Charting.Components;

using Brush = MindFusion.Drawing.Brush;
using SolidBrush = MindFusion.Drawing.SolidBrush;


namespace StressTest
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
			// create dashboard
			dashboard.Dock = DockStyle.Fill;
			dashboard.Anchor = AnchorStyles.Bottom | AnchorStyles.Left | AnchorStyles.Right | AnchorStyles.Top;
			dashboard.Padding = new Padding(10);
			dashboard.BackColor = Color.White;
			dashboard.Theme.PlotBackground = new MindFusion.Drawing.LinearGradientBrush(Color.White, Color.FromArgb(224, 233, 233), 90);
			dashboard.Theme.CommonSeriesFills = GetFills(255);
			dashboard.Theme.CommonSeriesStrokes = GetFills(255);

			var mainGrid = new GridPanel();
			mainGrid.HorizontalAlignment = LayoutAlignment.Stretch;
			mainGrid.VerticalAlignment = LayoutAlignment.Stretch;
			mainGrid.Columns.Add(new GridColumn());
			dashboard.RootPanel.Children.Add(mainGrid);

			// create plots grid
			var plotGrid = new GridPanel();
			plotGrid.GridColumn = 1;
			plotGrid.GridRow = 0;
			plotGrid.Columns.Add(new GridColumn());
			plotGrid.Columns.Add(new GridColumn());
			mainGrid.Children.Add(plotGrid);

			// add plot1
			var plot1 = new Plot2D();
			plot1.GridColumn = 0;
			plot1.VerticalScroll = false;
			plot1.AllowPan = false;
			plot1.HighlightStroke = new MindFusion.Drawing.SolidBrush(Color.Tomato);
			plot1.HighlightStrokeThickness = 1f;
			var lineRenderer = new LineRenderer(GetSeriesCollection());
			plot1.SeriesRenderers.Add(lineRenderer);
			plotGrid.Children.Add(plot1);

			// add plot2
			var plot2 = new Plot3D();
			plot2.GridColumn = 1;
			plot2.AllowPan = false;
			plot2.VerticalScroll = false;
			plot2.HighlightStroke = new MindFusion.Drawing.SolidBrush(Color.Tomato);
			plot2.HighlightStrokeThickness = 1f;
			var barRenderer = new BarOverlayRenderer3D(GetSeriesCollection());
			barRenderer.SeriesStyle = new PerSeriesStyle { Fills = GetFills(150) };
			barRenderer.BarSpacingRatio = 1;
			plot2.SeriesRenderers.Add(barRenderer);
			plotGrid.Children.Add(plot2);

			// add plot3
			var plot3 = new Plot2D();
			plot3.AllowPan = false;
			plot3.GridColumn = 2;
			plot3.VerticalScroll = false;
			plot3.HighlightStroke = new MindFusion.Drawing.SolidBrush(Color.Tomato);
			plot1.HighlightStrokeThickness = 1f;
			plot3.SeriesRenderers.Add(new StepRenderer(GetSeriesCollection()));
			plotGrid.Children.Add(plot3);

			// add axis
			var xa = new Axis() { Title = "Months" };
			var ya = new Axis() { MinValue=0, MaxValue=100000, Interval=5000, Title = "Revenues"};

			ya.NumberFormat = "C";
			var yAxis = new YAxisRenderer(ya, xa);
			yAxis.GridColumn = 0;
			yAxis.PlotLeftSide = true;
			yAxis.LabelsSource = plot1;
			yAxis.AxisStroke = new MindFusion.Drawing.SolidBrush(Color.SteelBlue);
			yAxis.AxisStrokeThickness = 1;
			yAxis.TitleBrush = new MindFusion.Drawing.SolidBrush(Color.SteelBlue);
			yAxis.TitleFontSize = 10f;
			yAxis.TitleFontStyle = FontStyle.Bold;
			yAxis.LabelBrush = new MindFusion.Drawing.SolidBrush(Color.SteelBlue);
			mainGrid.Children.Add(yAxis);
			
			// attach plots to axis
			plot1.XAxis = plot2.XAxis = plot3.XAxis = xa;
			plot1.YAxis = plot2.YAxis = plot3.YAxis = ya;
		}

		private ObservableCollection<Series> GetSeriesCollection()
		{
			ObservableCollection<Series> collection = new ObservableCollection<Series>();
			for (int i = 0; i < 3; i++)
			{
				if (i == 0)
				{
					collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
						new double[] { 25000, 50000, 40000, 55000 },
						new string[] { "January", "February", "March", "April" }) { Title = "Series 1" });
				}
				if (i == 1)
				{
					collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
					   new double[] { 30000, 70000, 65000, 15000 },
					   new string[] { "May", "June", "July", "August" }) { Title = "Series 2" });
				}
				if (i == 2)
				{
					collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
					   new double[] { 20000, 45000, 35000, 65000 },
					   new string[] { "September", "October", "November", "December" }) { Title = "Series 3" });
				}
			}
			return collection;
		}

		private List<MindFusion.Drawing.Brush> GetFills(int alpha)
		{
			var fills = new List<Brush>();

			fills.Add(new SolidBrush(Color.FromArgb(alpha, Color.FromArgb(102, 154, 204))));
			fills.Add(new SolidBrush(Color.FromArgb(alpha, Color.FromArgb(0, 0, 99))));
			fills.Add(new SolidBrush(Color.FromArgb(alpha, Color.FromArgb(206, 0, 0))));

			return fills;
		}
	}
}